magneticalc.Field_Widget.Field_Widget

# ``magneticalc`.`Field_Widget`.`Field_Widget``

class documentation

`class Field_Widget(QGroupBox2):`

Constructor: `Field_Widget(gui)`

View In Hierarchy

Field_Widget class.

Method | `__init__` | Populates the widget.
Method | `on_field_type_changed` | Gets called when the field type changed.
Method | `reload` | Reloads the widget.
Method | `set_field` | Sets the field. This will replace the currently set field in the model. Any underscored parameter may be left set to None in order to load its default value.
Method | `update` | Updates this widget.
Method | `update_controls` | Updates the controls.
Method | `update_labels` | Updates the labels.
Class Variable | `DistanceLimitMax` | Undocumented
Class Variable | `DistanceLimitMin` | Undocumented
Class Variable | `DistanceLimitPrecision` | Undocumented
Class Variable | `DistanceLimitStep` | Undocumented
Instance Variable | `distance_limit_spinbox` | Undocumented
Instance Variable | `field_type_checkboxes` | Undocumented
Instance Variable | `field_type_group` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `total_calculations_label` | Undocumented
Instance Variable | `total_skipped_calculations_label` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def on_field_type_changed(self, field_type: `int`, checked: `bool`):

Gets called when the field type changed.

Parameters
field_type: `int` | Field type
checked: `bool` | Boolean

def reload(self):

Reloads the widget.

def set_field(self, _field_type_: `int | None` = None, _distance_limit_: `float | None` = None, invalidate: `bool` = True, recalculate: `bool` = True):

Sets the field. This will replace the currently set field in the model. Any underscored parameter may be left set to None in order to load its default value.

Parameters
_field_type_: `int | None` | Field type
_distance_limit_: `float | None` | Distance limit
invalidate: `bool` | Enable to invalidate this model hierarchy level
recalculate: `bool` | Enable to trigger final recalculation

def update(self):

Updates this widget.

def update_controls(self):

Updates the controls.

def update_labels(self):

Updates the labels.

DistanceLimitMax: `int` =

Undocumented

DistanceLimitMin: `float` =

Undocumented

DistanceLimitPrecision: `int` =

Undocumented

DistanceLimitStep: `float` =

Undocumented

distance_limit_spinbox =

Undocumented

field_type_checkboxes: `dict` =

Undocumented

field_type_group =

Undocumented

gui =

Undocumented

total_calculations_label =

Undocumented

total_skipped_calculations_label =

Undocumented